use crate::prelude::*;

#[derive(Deserialize, Debug)]
pub struct Params {
    user_id: i32,
}

type Response = Result<Json<db::users::UserInfo>, StatusCode>;

pub async fn get(State(pool): State<Pool>, Query(params): Query<Params>) -> Response {
    let info = db::users::get(params.user_id, &pool)
        .await
        .handle_internal()?
        .ok_or(StatusCode::NOT_FOUND)?;
    Ok(Json(info))
}

pub async fn current(state: State<Pool>, claims: Claims) -> Response {
    get(
        state,
        Query(Params {
            user_id: claims.user_id,
        }),
    )
    .await
}
