use axum::Form;

use crate::{
    auth::{authenticate_user, Error, Token},
    prelude::*,
};

#[derive(Deserialize, Debug)]
pub struct Params {
    username: String,
    password: String,
}

pub async fn login(
    State(pool): State<Pool>,
    Form(payload): Form<Params>,
) -> Result<Json<Token>, Error> {
    let user_id = authenticate_user(&payload.username, &payload.password, &pool)
        .await
        .map_err(|_| Error::WrongCredentials)?
        .ok_or(Error::WrongCredentials)?;
    Claims::new(user_id).encode().map(Json)
}
