use validator::Validate;

use crate::prelude::*;

#[derive(Deserialize, Debug, Validate)]
pub struct Params {
    #[validate(email)]
    username: String,
    #[validate(email)]
    email: String,
}

pub async fn put(
    State(pool): State<Pool>,
    claims: Claims,
    Json(params): Json<Params>,
) -> Result<Json<db::users::UserInfo>, (StatusCode, String)> {
    params
        .validate()
        .map_err(|err| (StatusCode::BAD_REQUEST, err.to_string()))?;
    db::users::update(claims.user_id, &params.username, &params.email, &pool)
        .await
        .handle_internal()
        .map_err(|status| (status, String::new()))
        .map(Json)
}
