use axum::http::StatusCode;

type BoxError = Box<dyn std::error::Error>;

pub fn handle_error(error: impl Into<BoxError>) {
    let error: BoxError = error.into();
    tracing::error!(error);
}

pub trait ErrorHandlingExt<T, E>
where
    Self: Sized,
{
    fn handle(self, code: StatusCode) -> Result<T, StatusCode>;

    fn handle_internal(self) -> Result<T, StatusCode> {
        self.handle(StatusCode::INTERNAL_SERVER_ERROR)
    }
}

impl<T, E: Into<BoxError>> ErrorHandlingExt<T, E> for Result<T, E> {
    fn handle(self, code: StatusCode) -> Result<T, StatusCode> {
        self.map_err(|err| {
            handle_error(err);
            code
        })
    }
}
